@@ -276,7 +276,7 @@ class Tf2monCLI(BaseCLI):
     `CALLVOTE KICK` commands.
 
     When gamer kills an opponent, `%(prog)s` pushes a `taunt` onto the
-    `Spams` queue; on death, a `gurgle`. Enable/disable with `F3`.
+    `Spams` queue; on death, a `throe`. Enable/disable with `F3`.
 
     The monitor can only push actions onto the queues; the gamer must pop
     them for the action to be taken, or clear the queue to discard.
@@ -284,6 +284,34 @@ class Tf2monCLI(BaseCLI):
             ),
         )
 
+        self.parser.add_argument_group(
+            "Duels",
+            self.dedent(
+                """
+    The user-panel displays battles with opponents, grouped by weapon (and
+    its state when fired).
+
+        ┌─────────────────────────────────────────────────────────────────────┐
+        │Duels:                                                               │
+        │ 4 and  2 vs GLaDOS                                                  │
+        │             K  2 soldier        quake_rl                            │
+        │             K  1 pyro           flamethrower                        │
+        │             K  1 pyro     +crit flamethrower         +Low Gravity   │
+        │             D  2 heavy          minigun                             │
+        │ 5 and  0 vs CreditToTeam                                            │
+        │             K  2 soldier        quake_rl                            │
+        │             K  2 pyro     +crit flamethrower                        │
+        │             K  1 pyro           flamethrower                        │
+        │ 3 and  1 vs Aperture Science Prototype XR7                          │
+        │             K  1 soldier        world                               │
+        │             K  1 soldier        quake_rl             +Invisibility  │
+        │             K  1 pyro     +crit flamethrower                        │
+        │             D  1 demo           player                              │
+        └─────────────────────────────────────────────────────────────────────┘
+                """
+            ),
+        )
+
         self.parser.add_argument_group(
             "Function Keys",
             self.dedent(
@@ -292,7 +320,7 @@ class Tf2monCLI(BaseCLI):
 
         F1=HELP                 Display help.
         F2=TOGGLE-DEBUG         Control `say` vs `echo`.
-        F3=TOGGLE-TAUNT         Enable taunts and gurgles.
+        F3=TOGGLE-TAUNT         Enable taunts and throes.
         F4=TOGGLE-KD            Include kd-ratio in messages.
         F5=TOGGLE-USER-PANEL    Control contents of the user panel;
                                 USER=show duels, weapons, captures, etc.
